==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Rulers and Scrollbars</source>
        <translation>Ravnila in drsniki</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Prikaži ravnila</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Prikaži drsnike</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Kazalec</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Prikaži kazalni križec</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Prikaži velik kazalni križec</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Samodejna povečava</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Margin (px):</source>
        <translation>Rob (px):</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Color Adjustment</source>
        <translation>Prilagoditev barv</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Prepreči belo na bel / črno na črn zaslon</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Prag svetlosti barv:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Vrste črt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Povečava vzorca ko je debelina črte 0.00mm:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Samodejno uporabi zaslonske črte v prikazu modela</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch linetypes</source>
        <translation>Samodejno preklopi način črt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Performance</source>
        <translation>Optimizacija</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Number of preview entities:</source>
        <translation>Število entitet v predogledu:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Prag prikaza višine besedila:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Selection</source>
        <translation>Izbor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Lepljivi način</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Izgled grafike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Izhodišče</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Prikaži velike izhodiščne osi</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Ravnila in drsniki</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Prikaži ravnila</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Prikaži drsnike</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Kazalec</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Prikaži kazalni križec</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Prikaži velik kazalni križec</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Samodejna povečava</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Rob (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Prilagoditev barv</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Prepreči belo na bel / črno na črn zaslon</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Prag svetlosti barv:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Vrste črt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Samodejno preklopi na zaslonske črte v prikazu modela</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Povečuj vzorce črt glede na debelino črte</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Povečava vzorca ko je debelina črte 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Prikaz in optimizacija</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Prikaži entitete z več kot N pikami kot neprekinjene:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Najmanjši kot koraka za izris krivulje (stopinje):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Glajenje robov provzeto vklopljeno</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Iztek časa za izris šrafur:</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Samodejno uporabi zaslonske črte v prikazu modela</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Samodejno preklopi način črt</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Optimizacija</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Število entitet v predogledu:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Prag prikaza višine besedila (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Prikaži loke kot črt, če je kot manjši od (stopinje): </translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Prag prikaza višine besedila:</translation>
    </message>
    <message>
        <location line="+331"/>
        <source>Selection</source>
        <translation>Izbor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Lepljivi način</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Izgled grafike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
</context>
</TS>
